@@ -1,4 +1,4 @@
-/* $Id: config.h,v 1.19 2009/01/24 16:20:51 phil Exp $ */
+/* $Id: config.h,v 1.22 2012/01/04 18:54:35 phil Exp $ */
 
 /*
  * Windows32 config.h 1/27/2002
@@ -60,3 +60,8 @@
 #define isnan		_isnan
 #define popen		_popen
 #define pclose		_pclose
+
+/* optional features: */
+#define PML_TIME
+#define PML_RANDOM
+#define HAVE_SLEEP
