@@ -1,4 +1,4 @@
-/* $Id: dynamic.c,v 1.5 2003/04/21 22:44:01 phil Exp $ */
+/* $Id: dynamic.c,v 1.6 2010/12/04 06:14:10 phil Exp $ */
 
 /* allocate dynamic region on BSD */
 
@@ -24,7 +24,7 @@ extern void *malloc();
 
 char *
 dynamic( size )
-    int size;
+    size_t size;
 {
     return malloc(size);
 }
