@@ -1,4 +1,4 @@
-/* $Id: dynamic.c,v 1.4 2001/12/03 01:14:10 phil Exp $ */
+/* $Id: dynamic.c,v 1.5 2010/12/04 06:14:10 phil Exp $ */
 
 /* allocate dynamic region */
 
@@ -14,7 +14,7 @@ extern void *malloc();
 
 char *
 dynamic( size )
-    int size;
+    size_t size;
 {
     return malloc(size);
 }
