@@ -1,4 +1,4 @@
-/* $Id: execute.c,v 1.6 2003/07/04 20:01:09 phil Exp $ */
+/* $Id: execute.c,v 1.7 2012/01/04 00:09:09 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -25,8 +25,8 @@ void
 execute(buf)
     char *buf;
 {
-    execl(SH_PATH, "sh", "-c", buf, 0); /* XXX SH_NAME? */
+    execl(SH_PATH, "sh", "-c", buf, NULL); /* XXX SH_NAME? */
 
     /* must not have found shell; try alternate */
-    execl(SH_PATH2, "sh", "-c", buf, 0); /* XXX SH_NAME2? */
+    execl(SH_PATH2, "sh", "-c", buf, NULL); /* XXX SH_NAME2? */
 }
