@@ -1,4 +1,4 @@
-/* $Id: io.c,v 1.121 2005/12/05 18:11:09 phil Exp $ */
+/* $Id: io.c,v 1.123 2010/12/21 05:55:05 phil Exp $ */
 
 /*
  * I/O support for CSNOBOL4
@@ -206,6 +206,7 @@ struct iovars {
 #include "vars.h"
 #else  /* NO_STATIC_VARS not defined */
 extern int rflag;			/* from init.c */
+extern int lflag;			/* from init.c */
 static struct iovars iov;
 #endif /* NO_STATIC_VARS not defined */
 
@@ -891,12 +892,12 @@ io_printf
 	switch (c) {
 	case 'd':			/* plain decimal */
 	    dp = va_arg(vp, struct descr *);
-	    sprintf(temp, "%d", (long)D_A(dp)); /* XXX handle LP32LL64 int_t */
+	    sprintf(temp, "%ld", (long)D_A(dp)); /* XXX handle LP32LL64 int_t */
 	    COPYTEMP;
 	    break;
 	case 'D':			/* padded decimal */
 	    dp = va_arg(vp, struct descr *);
-	    sprintf(temp, "%15d", (long)D_A(dp)); /* XXX handle LP32LL64 int_t */
+	    sprintf(temp, "%15ld", (long)D_A(dp)); /* XXX handle LP32LL64 int_t */
 	    COPYTEMP;
 	    break;
 	case 'F':			/* padded float */
@@ -1380,6 +1381,13 @@ io_ecomp()				/* XECOMP */
     struct unit *up;
     struct file *fp;
 
+    if (lflag) {
+	/* if -l was given, switch OUTPUT to stdout! */
+
+	/* XXX check return?! */
+	io_mkfile2( UNITO, stdout, STDOUT_NAME, FL_NOCLOSE );
+    }
+
     if (rflag == 0) {
 	/* if -r was not given, switch INPUT to stdin!! */
 
@@ -1387,6 +1395,7 @@ io_ecomp()				/* XECOMP */
 	io_mkfile2( UNITI, stdin, STDIN_NAME, FL_NOCLOSE );
 	return;
     }
+
     /*
      * else (start INPUT after END stmt)
      * save the file position the data begins at for rewind.
