@@ -1,4 +1,4 @@
-/* $Id: dynamic.c,v 1.3 2003/04/21 22:44:01 phil Exp $ */
+/* $Id: dynamic.c,v 1.6 2010/12/04 06:14:10 phil Exp $ */
 
 /* allocate dynamic region for POSIX 1003.1b-1993 systems */
 
@@ -15,6 +15,13 @@
 extern void *malloc();
 #endif /* HAVE_STDLIB_H not defined */
 
+/* prefer standard POSIX interface; fall back to BSD */
+#if !defined(POSIX_MADV_RANDOM) && defined(MADV_RANDOM)
+#define POSIX_MADV_RANDOM MADV_RANDOM
+#define POSIX_MADV_NORMAL MADV_NORMAL
+#define posix_madvise madvise
+#endif /* !defined(POSIX_MADV_RANDOM) && defined(MADV_RANDOM) */
+
 /* for lib.h: */
 #include <stdio.h>
 #include "h.h"
@@ -22,11 +29,11 @@ extern void *malloc();
 #include "lib.h"			/* own prototypes */
 
 static char *dbase;
-static int dsize;
+static size_t dsize;
 
 char *
 dynamic( size )
-    int size;
+    size_t size;
 {
     dsize = size;
     dbase = malloc(size);
@@ -38,7 +45,7 @@ vm_gc_advise(gc)
     int gc;
 {
     if (gc)
-	madvise(dbase, dsize,  MADV_RANDOM); /* random during GC */
+	posix_madvise(dbase, dsize,  POSIX_MADV_RANDOM); /* random during GC */
     else
-	madvise(dbase, dsize,  MADV_NORMAL); /* normal */
+	posix_madvise(dbase, dsize,  POSIX_MADV_NORMAL); /* normal */
 }
